@@ -581,6 +581,8 @@ class SearchDialog(QDialog, Ui_searchDialog):
             SearchSettings.recentSearches.removeAt(30)
         SearchSettings.recentSearches.prepend(searchString)
         searchWindow = cutetubewindows.SearchResultsWindow(self, searchString, searchOrder, self.username)
+        self.connect(searchWindow, SIGNAL("queueChanged(int)"), self.queueChanged)
+        self.connect(searchWindow, SIGNAL("downloadsChanged(int)"), self.downloadsChanged)
         
     def queueChanged(self, queueLength):
         """
